/*
  Blink built-in LED and an external LED on Pin 5 for Arduino Mega2560

  BE SURE TO USE SKETCH | EXPORT BINARY after each build/upload
  so updates can be loaded into SimulIDE.
  
//modified Ron Kessler
1/4/2023

To allow both LEDs to be synchronized, we will set the bits in the CPU
registers directly.

Each register bit can be set HIGH (1) or LOW (0).
We have been using the statement: pinMode(OnboardLED, OUTPUT) to do that.
Pin 13 is mapped to PORT B on the CPU.
Each port has 3 registers: Data Direction Reg (DDR), Port, & Pin. DDR sets bit for output(1) or Reading(0).
Port tells which bits to manipulate and PIN will read current bits.

The onboard LED is on pin 13 and maps to PortB7 (PB7) or bit 7 in the PortB register.
My second LED is wired to pin #11 which maps to PB5 or bit 5 in the PortR register.

To program the registers directly, we use the following:
1. Set DDRB = 0b10100000     bits 5 & 7 set for output.
2. Set PortB = 0b1010000     bits 5 & 7 set HIGH.
3. Set PortB = 0b00000000    set bits 5 & 7 LOW or 0.

The 0b (zero b) notation defines a binary pattern. You could use hexidecimal notation also.
For hex, use 0x (zero x) as the prefix. For example, 10100000 = 0xA0 in hex.

Open the .hex file for this program in notepad. It s ~= 3K in size.
Do the same for the other MEGA project and it is ~=5K.
Imagine the difference with a large app.

ALSO, you can use bitWrite/bitRead in the IDE if you want to. I think bit manipulation
is faster and cool!  The delay function can be replaced with another library for much
more accuracy. I do that in Microchip Studio.

I suspect programming registers is much faster in MC Studio.

***************RUN THIS CODE TO SET CPU REGISTERS DIRECTLY********************
*/


//---in the simulator I added a Yellow LED to pin 5

void setup() {
  //STEP 1: SET BITS FOR OUTPUT  
  DDRB = 0b10100000;        //set bits 5 & 7 for output
  
}

void loop() {

  //STEP 2: SET BITS 5 & 7 HIGH
  PORTB = 0b10100000;     // turn bits 5 & 7 on so pins 11 & 13 go HIGH and turn on LEDs at the same time!
    
  delay(500);

  //STEP 3: TRUN OFF BITS 5 & 7
  PORTB = 0b00000000;     //now turn off 5 & 7 (all of them actually in this case)
  
  delay(500);
}
